@@ -23,6 +23,8 @@ class AvailableBalance:
         self.value = value
         self.currency = currency
 
+        self.kwargs = kwargs
+
 
 class Account:
     """
@@ -60,6 +62,8 @@ class Account:
         self.ready = ready
         self.hold = AvailableBalance(**hold) if hold is not None else None
 
+        self.kwargs = kwargs
+
     @classmethod
     def from_response(cls, response: requests.Response) -> 'Account':
         """
@@ -99,6 +103,8 @@ class AccountsPage:
         self.cursor = cursor
         self.size = size
 
+        self.kwargs = kwargs
+
     @classmethod
     def from_response(cls, response: requests.Response) -> 'AccountsPage':
         """
@@ -110,3 +116,6 @@ class AccountsPage:
 
         result = json.loads(response.text)
         return cls(**result)
+
+    def __iter__(self):
+        return self.accounts.__iter__()
