@@ -70,6 +70,8 @@ class OrderError:
         self.preview_failure_reason = preview_failure_reason
         self.new_order_failure_reason = new_order_failure_reason
 
+        self.kwargs = kwargs
+
 
 class LimitGTC:
     """
@@ -85,6 +87,8 @@ class LimitGTC:
         self.limit_price = limit_price
         self.post_only = post_only
 
+        self.kwargs = kwargs
+
 
 class LimitGTD:
     """
@@ -103,6 +107,8 @@ class LimitGTD:
         self.end_time = datetime.strptime(end_time if len(
             end_time) <= 27 else end_time[:26]+'Z', "%Y-%m-%dT%H:%M:%SZ")
 
+        self.kwargs = kwargs
+
 
 class MarketIOC:
     """
@@ -116,6 +122,8 @@ class MarketIOC:
         self.quote_size = quote_size
         self.base_size = base_size
 
+        self.kwargs = kwargs
+
 
 class StopLimitGTC:
     """
@@ -137,6 +145,8 @@ class StopLimitGTC:
         self.stop_price = stop_price
         self.stop_direction = stop_direction
 
+        self.kwargs = kwargs
+
 
 class StopLimitGTD:
     """
@@ -162,6 +172,8 @@ class StopLimitGTD:
             end_time) <= 27 else end_time[:26]+'Z', "%Y-%m-%dT%H:%M:%SZ")
         self.stop_direction = stop_direction
 
+        self.kwargs = kwargs
+
 
 class OrderConfiguration:
     """
@@ -188,6 +200,8 @@ class OrderConfiguration:
         self.stop_limit_stop_limit_gtd = StopLimitGTD(
             **stop_limit_stop_limit_gtd) if stop_limit_stop_limit_gtd is not None else None
 
+        self.kwargs = kwargs
+
 
 class Order:
     """
@@ -295,6 +309,8 @@ class Order:
 
         self.order_error = OrderError(**order_error) if order_error is not None else None
 
+        self.kwargs = kwargs
+
     @classmethod
     def from_create_order_response(cls, response: requests.Response) -> 'Order':
         """
@@ -357,6 +373,8 @@ class OrdersPage:
         self.cursor = cursor
         self.sequence = sequence
 
+        self.kwargs = kwargs
+
     @classmethod
     def from_response(cls, response: requests.Response) -> 'OrdersPage':
         """
@@ -369,6 +387,9 @@ class OrdersPage:
         result = json.loads(response.text)
         return cls(**result)
 
+    def __iter__(self):
+        return self.orders.__iter__()
+
 
 class OrderCancellation:
     """
@@ -384,6 +405,8 @@ class OrderCancellation:
         self.failure_reason = failure_reason
         self.order_id = order_id
 
+        self.kwargs = kwargs
+
 
 class OrderBatchCancellation:
     """
@@ -395,6 +418,8 @@ class OrderBatchCancellation:
     def __init__(self, results: List[OrderCancellation], **kwargs) -> None:
         self.results = results
 
+        self.kwargs = kwargs
+
     @classmethod
     def from_response(cls, response: requests.Response) -> 'Order':
         """
@@ -464,6 +489,8 @@ class Fill:
         self.user_id = user_id
         self.side = side
 
+        self.kwargs = kwargs
+
 
 class FillsPage:
     """
@@ -482,6 +509,8 @@ class FillsPage:
 
         self.cursor = cursor
 
+        self.kwargs = kwargs
+
     @classmethod
     def from_response(cls, response: requests.Response) -> 'FillsPage':
         """
@@ -493,3 +522,6 @@ class FillsPage:
 
         result = json.loads(response.text)
         return cls(**result)
+
+    def __iter__(self):
+        return self.fills.__iter__()
