@@ -21,6 +21,18 @@ class ProductType(Enum):
     SPOT = "SPOT"
 
 
+GRANULARITY_MAP_IN_MINUTES = {
+    "ONE_MINUTE": 1,
+    "FIVE_MINUTE": 5,
+    "FIFTEEN_MINUTE": 15,
+    "THIRTY_MINUTE": 30,
+    "ONE_HOUR": 60,
+    "TWO_HOUR": 120,
+    "SIX_HOUR": 360,
+    "ONE_DAY": 1440,
+}
+
+
 class Granularity(Enum):
     """
     Enum representing time range for product candles.
@@ -139,6 +151,8 @@ class Product:
         self.base_display_symbol = base_display_symbol
         self.quote_display_symbol = quote_display_symbol
 
+        self.kwargs = kwargs
+
     @classmethod
     def from_response(cls, response: requests.Response) -> 'Product':
         """
@@ -167,6 +181,8 @@ class ProductsPage:
 
         self.num_products = num_products
 
+        self.kwargs = kwargs
+
     @classmethod
     def from_response(cls, response: requests.Response) -> 'ProductsPage':
         """
@@ -179,6 +195,9 @@ class ProductsPage:
         result = json.loads(response.text)
         return cls(**result)
 
+    def __iter__(self):
+        return self.products.__iter__()
+
 
 class Candle:
     """
@@ -200,6 +219,8 @@ class Candle:
         self.close = close
         self.volume = volume
 
+        self.kwargs = kwargs
+
 
 class CandlesPage:
     """
@@ -211,6 +232,8 @@ class CandlesPage:
     def __init__(self, candles: List[Candle], **kwargs) -> None:
         self.candles = list(map(lambda x: Candle(**x), candles)) if candles is not None else None
 
+        self.kwargs = kwargs
+
     @classmethod
     def from_response(cls, response: requests.Response) -> 'CandlesPage':
         """
@@ -223,6 +246,9 @@ class CandlesPage:
         result = json.loads(response.text)
         return cls(**result)
 
+    def __iter__(self):
+        return self.candles.__iter__()
+
 
 class Trade:
     """
@@ -256,6 +282,8 @@ class Trade:
         self.bid = bid
         self.ask = ask
 
+        self.kwargs = kwargs
+
 
 class TradesPage:
     """
@@ -275,6 +303,8 @@ class TradesPage:
         self.best_bid = best_bid
         self.best_ask = best_ask
 
+        self.kwargs = kwargs
+
     @classmethod
     def from_response(cls, response: requests.Response) -> 'TradesPage':
         """
@@ -286,3 +316,6 @@ class TradesPage:
 
         result = json.loads(response.text)
         return cls(**result)
+
+    def __iter__(self):
+        return self.trades.__iter__()
